@@ -14,10 +14,11 @@ from classiq_interface.combinatorial_optimization import (
     optimization_problem,
     sense,
 )
+from classiq_interface.combinatorial_optimization.preferences import QAOAPreferences
+from classiq_interface.executor.execution_preferences import OptimizerPreferences
 from classiq_interface.executor.result import ExecutionData, ExecutionStatus
 from classiq_interface.generator import result as generator_result
 from classiq_interface.generator.result import GeneratedCircuit
-from classiq_interface.hybrid import vqe_problem
 
 from classiq import api_wrapper
 from classiq.exceptions import (
@@ -31,11 +32,14 @@ class CombinatorialOptimization:
     def __init__(
         self,
         model: ConcreteModel,
-        vqe_preferences: Optional[vqe_problem.VQEPreferences] = None,
+        qaoa_preferences: Optional[QAOAPreferences] = None,
+        optimizer_preferences: Optional[OptimizerPreferences] = None,
         backend_preferences: Optional[BackendPreferences] = None,
     ):
-        if vqe_preferences is None:
-            vqe_preferences = vqe_problem.VQEPreferences()
+        if qaoa_preferences is None:
+            qaoa_preferences = QAOAPreferences()
+        if optimizer_preferences is None:
+            optimizer_preferences = OptimizerPreferences()
         if backend_preferences is None:
             backend_preferences = IBMBackendPreferences(
                 backend_service_provider="IBMQ", backend_name="aer_simulator"
@@ -45,7 +49,8 @@ class CombinatorialOptimization:
         self._serialized_model = model_serializer.to_json(model, return_dict=True)
         self._problem = optimization_problem.OptimizationProblem(
             serialized_model=self._serialized_model,
-            vqe_preferences=vqe_preferences,
+            qaoa_preferences=qaoa_preferences,
+            optimizer_preferences=optimizer_preferences,
             backend_preferences=backend_preferences,
         )
 
